/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * COPYING NOTES
 *
 * ServerSocket.cpp -- Implementation of the ServerSocket class
 * 
 * Copyright (C) 2002, Rob Tougher <rtougher@yahoo.com>
 *   as heavily derived from Issue 74 of Linux Gazette, January 2002
 * Copyright (C) 2002 Roberto A. Foglietta <robang@libero.it>
 * Copyright (C) 2002 GEA-Automotive <fogliettar@gea-automotive.com>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * 
 * REVISION NOTES:
 * released 21-10-2002 by Roberto A. Foglietta
 */


#include "ServerSocket.h"
#include "SocketException.h"


ServerSocket::ServerSocket (int port)
{
	if (!Socket::create ()) {
		throw SocketException ("Could not create server socket.");
	}

	if (!Socket::bind (port)) {
		throw SocketException ("Could not bind to port.");
	}

	if (!Socket::listen ()) {
		throw SocketException ("Could not listen to socket.");
	}
	
	//Socket::set_non_blocking (TRUE);
}

ServerSocket::~ServerSocket ()
{
}


const ServerSocket &
ServerSocket::operator << (const std::string & s) const
{
	if (!Socket::send (s)) {
		throw SocketException ("Could not write to socket.");
	}

	return *this;

}


const ServerSocket &
ServerSocket::operator >> (std::string & s) const
{
	if (!Socket::recv (s)) {
		throw SocketException ("Could not read from socket.");
	}

	return *this;
}

void
ServerSocket::accept (ServerSocket & sock)
{
	if (!Socket::accept (sock)) {
		throw SocketException ("Could not accept socket.");
	}
	
	//Socket::set_non_blocking (TRUE);
}
